@@ -4,7 +4,7 @@
 
 ;; Author: Vasilij Schneidermann <mail@vasilij.de>
 ;; URL: https://github.com/wasamasa/nov.el
-;; Version: 0.2.4
+;; Version: 0.2.5
 ;; Package-Requires: ((dash "2.12.0") (esxml "0.3.3") (emacs "24.4"))
 ;; Keywords: hypermedia, multimedia, epub
 
@@ -410,7 +410,7 @@ Each alist item consists of the identifier and full path."
 (defun nov-url-filename-and-target (url)
   "Return a list of URL's filename and target."
   (setq url (url-generic-parse-url url))
-  (list (url-filename url) (url-target url)))
+  (mapcar 'url-unhex-string (list (url-filename url) (url-target url))))
 
 (defun nov-insert-image (path)
   "Insert an image for PATH at point.
